@@ -6,17 +6,31 @@ from zope.interface import implementer
 
 # Portuguese character mapping
 mapping = {
-    192: u'A', 193: u'A', 194: u'A', 195: u'A',
-    201: u'E', 202: u'E',
+    192: u'A',
+    193: u'A',
+    194: u'A',
+    195: u'A',
+    201: u'E',
+    202: u'E',
     205: u'I',
-    211: u'O', 212: u'O', 213: u'O',
-    218: u'U', 220: u'U',
+    211: u'O',
+    212: u'O',
+    213: u'O',
+    218: u'U',
+    220: u'U',
     199: u'C',
-    224: u'a', 225: u'a', 226: u'a', 227: u'a',
-    233: u'e', 234: u'e',
+    224: u'a',
+    225: u'a',
+    226: u'a',
+    227: u'a',
+    233: u'e',
+    234: u'e',
     237: u'i',
-    243: u'o', 244: u'o', 245: u'o',
-    250: u'u', 252: u'u',
+    243: u'o',
+    244: u'o',
+    245: u'o',
+    250: u'u',
+    252: u'u',
     231: u'c',
 }
 
